figure14 <- function() {

  library(lattice)
  
  ## Graphical settings
  str     <- trellis.par.get("strip.background")
  str$col <- rep("transparent",length(str$col))
  trellis.par.set("strip.background",str)

  grl     <- trellis.par.get("reference.line")
  grl$col <- "black"
  grl$lty <- 3
  trellis.par.set("reference.line",grl)

  grl     <- trellis.par.get("box.rectangle")
  grl$col <- "black"
  trellis.par.set("box.rectangle",grl)

  grl     <- trellis.par.get("box.umbrella")
  grl$col <- "black"
  trellis.par.set("box.umbrella",grl)

  adata <- datab4[!duplicated(datab4$ID),]

  newdata <- stack(adata,select=c("CRCL","SEX"))
  newdata[,"ID"] <- rep(adata$ID,2)
  newdata[,"ETA12"] <- rep(adata$ETA12,2)  
  levels(newdata$ind) <- c("Creatinine clearance (mL/min)","SEX (0=male)")

  xplot <- xyplot(ETA12~values|ind,newdata,
                  prepanel=function(x,y) {
                    if(length(levs <- unique(x)) ==2) {
                        xlim <- as.character(sort(levs))
                    } else {
                        xlim <- range(x)
                    }
                    list(xlim=xlim,ylim=c(-0.88693,0.85766))
                  },
                  groups=ID,
                  ylab="Unexplained variability in CL (ETA)",
                  xlab="Covariates",
                  layout=c(2,1),
                  aspect=1,
                  scales=list(y=list(at=c(-0.5,0,0.5)),x=list(relation="free")),
                  panel=function(x,y,...) {
                    panel.grid(h=-1,v=F)
                    if(length(unique(x)) >2) {
                      panel.superpose(x,y,col="black",pch=1,...)
                      panel.loess(x,y,col="black",lwd=2)
                    } else {
                      x <- as.factor(x)
                      levels(x) <- c("Males","Females")
                      panel.bwplot(x,y,horizontal=F,varwidth=T)
                    }
                    }
                    )
  print(xplot)
}
