figure25 <- function() {

  library(lattice)
  library(grid)
  
  N <- 25 # Number of simulated data sets
  data      <- read.nm.tables(3,table.names=c("simtab"))
  names(data)[names(data)=="DV"] <- "Observations"
  data$Observations   <- as.factor(data$Observations)
  names(data)[names(data)=="SPR"] <- "Predictions"
  data$Predictions  <- as.factor(data$Predictions)
  data$DOSE <- as.factor(data$DOSE)
  data$N    <- rep(1:N,each=nrow(data)/N)
  
  tmp3 <- trellis.par.get("strip.background")
  tmp3$col <- rep("white",6)
  trellis.par.set("strip.background",tmp3)
  

  for(i in 1:N) {
    if(i==1) {
      tmpbig <- make.sb.data("Predictions",data[data$N==i,],idv="DOSE")
      bigvec <- as.vector(t(apply(matrix(tmpbig$values,nrow=4),1,cumsum)))
      res    <- data.frame(values=bigvec,
                           DOSE=tmpbig$DOSE,
                           N=rep(i,length(bigvec)),
                           dv = rep(1:6,each=length(unique(tmpbig$DOSE))))
      
    } else {
      tmpbig <- make.sb.data("Predictions",data[data$N==i,],idv="DOSE")
      bigvec <- as.vector(t(apply(matrix(tmpbig$values,nrow=4),1,cumsum)))
      res1   <- data.frame(values=bigvec,
                           DOSE=tmpbig$DOSE,
                           N=rep(i,length(bigvec)),
                           dv = rep(1:6,each=length(unique(tmpbig$DOSE))))
      res    <- rbind(res,res1)
    }
  }

  ## Select the highest and lowest cumsums. The resulting data frame is
  ## 24x4
  res2 <- data.frame(max=rep(0,24),
                     min=rep(0,24),
                     DOSE=res$DOSE[1:24],
                     dv=res$dv[1:24]
                     )
  for(dv in unique(res2$dv)) {
    for(dose in levels(res2$DOSE)) {
      res2$min[res2$dv==dv & res2$DOSE==dose] <-
        min(res$values[res$dv==dv & res$DOSE==dose])

      res2$max[res2$dv==dv & res2$DOSE==dose] <-
        max(res$values[res$dv==dv & res$DOSE==dose])
    }
  }
  res2 <- res2[res2$dv!=6,]
          

  ## Make the data for the stacked bars
  tmp1 <- make.sb.data("Observations",data,idv=c("DOSE"))
  names(tmp1)[1] <- "Observations"
  tmp2 <- make.sb.data("Predictions",data,idv=c("DOSE"))
  names(tmp2)[1] <- "Predictions"
  tmp <- cbind(tmp1,tmp2[,"Predictions"])
  
  names(tmp)[c(2,4)] <- c("Pind","Predictions")
  data <- stack.xpose(tmp,c("Observations","Predictions"),c("Pind","DOSE"))

  barchart(values~DOSE|ind,data,stack=T,groups=Pind,
           aspect=1,
           xlab="Dose",
           ylab="Probability",
           key=list(
             space="right",
             rectangles=list(col=rev(c("white","lightgray","grey","darkgrey","dimgrey","black"))),
             text      =list(as.character(5:0))
             ),
           legend=list(top=list(fun=draw.key(list(
                                  text=list("Prediction interval"),
                                  lines=list(
                                    col="slategrey",
                                    lwd=5)
                                  )))),
           col=c("white","lightgray","grey","darkgrey","dimgrey","black"),
           tdat=res2,
           panel=function(x,y,tdat,...) {
             panel.barchart(x,y,...)

             for(i in unique(tdat$dv)) {
               grid.polygon(c(tdat$DOSE[tdat$dv==i],
                              rev(tdat$DOSE[tdat$dv==i])),
                            c(tdat$min[tdat$dv==i],
                              rev(tdat$max[tdat$dv==i])),
                            default.units="native",
                            gp=gpar(fill="slategrey",col=NULL,lty=2))
             }

             tmp <- as.list(substitute(list(...)))
             gr  <- tmp$groups[tmp$subscripts]

             yy <- as.vector(t(apply(matrix(y,nrow=4),1,cumsum)))
             yy   <- yy[gr!="5"]
             xx   <- x[gr!="5"]
             gr   <- gr[gr!="5"]

             panel.superpose(xx,yy,groups=gr,
                             subscripts=1:20,
                             type="b",col="black",lty=2,lwd=2,pch=16)
           }
           )
}
