figure29 <- function() {

  library(lattice)
  
  str     <- trellis.par.get("strip.background")
  str$col <- rep("transparent",length(str$col))
  trellis.par.set("strip.background",str)

  datat <- datab4[!duplicated(datab4$ID),]
  crcl <- datat$CRCL
  etas <- datat$ETA12
  dose <- 500
  th   <- 0.00952
  tvcl <- 16.7
                                        
  cli  <- tvcl*(1+th*(crcl-90))*exp(etas)
  target <- dose/median(cli)
  
  noadj  <- dose/cli
  perfect <- dose/(median(cli)*exp(etas))
    
  ## Use two doses
  
  cutoff  <- median(crcl)
  lowCL   <- cli[crcl <=cutoff]
  highCL  <- cli[crcl >cutoff]
  lowdose <- target*median(lowCL)
  highdose<- target*median(highCL)
  
  adjusted1 <- rep(0,length(crcl))
  adjusted1 <- ifelse(crcl <= cutoff,lowdose/cli,adjusted1)
  adjusted1 <- ifelse(crcl > cutoff,highdose/cli,adjusted1)
  
  ## Use three doses 
  cutoff1 <- 35
  cutoff2 <- 80
  lowCL  <-  cli[crcl <=cutoff1]
  medCL  <- cli[crcl >cutoff1 & crcl <= cutoff2]
  highCL <- cli[crcl >cutoff2]
  
  ## dose = CSS*CL
  lowdose <- target*median(lowCL)
  meddose <- target*median(medCL)
  highdose<- target*median(highCL)
    
  adjusted <- rep(0,length(crcl))
  adjusted <- ifelse(crcl <= cutoff1,lowdose/cli,adjusted)
  adjusted <- ifelse(crcl >cutoff1 & crcl <= cutoff2,meddose/cli,adjusted)
  adjusted <- ifelse(crcl > cutoff2,highdose/cli,adjusted)
  Cave <- c(noadj,adjusted1,adjusted,perfect)
  CRCL <- c(crcl,crcl,crcl,crcl)
  
  Type <- c(rep(1,length(crcl)),
            rep(2,length(crcl)),
            rep(3,length(crcl)),
            rep(4,length(crcl)))
  
  mydf <- data.frame(Cave=Cave,CRCL=CRCL,Type=Type)
  mydf$Type <- as.factor(mydf$Type)
  levels(mydf$Type) <- c("No dose adjustment","Two dose levels",
                         "Three dose levels","Individualised doses")
  xplot <- xyplot(Cave~CRCL|Type,mydf,
                  aspect=1,
                  ylab="Average concentration (ng/mL)",
                  xlab="Creatinine clearance (mL/min)",
                  layout=c(4,1),
                  panel=function(x,y,...) {
                    panel.xyplot(x,y,col="black")
                    panel.loess(x,y,lwd=2)
                  }
                  )
  print(xplot)
  
  return()
  
}
