figure3 <- function() {

  library(lattice)
  ## Graphical settings
  grl     <- trellis.par.get("reference.line")
  grl$col <- "black"
  grl$lty <- 3
  trellis.par.set("reference.line",grl)
  
  ## Create subset
  adata  <- datab4
  subci  <- 0.99 # The limits of the sampling region
  frac   <- 0.50  # Probability of being plotted if in the region

  yres <- residuals(loess(DV~TIME,adata))
  lims <- quantile(yres,
                   probs=c(1-subci,subci))
  

  mp3fun <- function(x,lims) {
    ret <- 1
    if(any(x < lims[1])) ret <- 0
    if(any(x > lims[2])) ret <- 0
    ret
  }
  
  RR     <- tapply(yres,adata$ID,FUN="mp3fun",lim=lims)
  ids    <- unique(adata[,"ID"])
  RRR    <- sample(c(0,1),size=length(ids),replace=TRUE,
                         prob=c(frac,1-frac))
                         
  tmp    <- data.frame(ID=as.factor(names(RR)),
                       R=RR*RRR)
                
  names(tmp) <- c("ID","R")
  newdata       <- merge(tmp,adata,by="ID",sort=FALSE)

  ## Do some final housekeeping tasks
  newdata             <- newdata[newdata$WRES!=0 & newdata$TAD !=0,]
  ids                 <- newdata[,"ID"]
  
  xplot <- xyplot(DV~TAD,data=newdata,
                  odat = newdata,
                  groups = ID,
                  subset=R==0,
                  aspect=1,
                  ids  = ids,
                  xlab = "Time after dose (h)",
                  ylab = "Observed concentration (ng/mL)",
                  panel=function(x,y,ids,subscripts,odat,...) {
                    panel.grid()
                    ord <- order(x)
                    panel.superpose(x[ord],y[ord],subscripts[ord],
                                    ...,type="b",pch="o",cex=0.7,
                                    col="black",lty=1)

                    panel.loess(odat$TAD,
                                odat$DV,lwd=4,lty=1,col="black")
                    
                    ## Adding the id-labels
                    idd  <- ids[subscripts]
                    yres <- residuals(loess(y~x))

                    ord     <- order(yres)
                    ordy    <- y[ord]
                    ordx    <- x[ord]
                    ordidd  <- idd[ord]
                    ## Number of data points to plot
                    idsext <- ceiling(length(x)*0.02)

                    ll <- length(ordx)

                    ## Upper points
                    ltext(ordx[(ll-idsext+1):ll],
                          ordy[(ll-idsext+1):ll],
                             ordidd[(ll-idsext+1):ll],
                             cex=0.7)
                    ## Lower points
                    ltext(ordx[1:idsext],
                             ordy[1:idsext],
                             ordidd[1:idsext],
                             cex=0.7)
                  }
                  )

  print(xplot)
  invisible()
}
