figure4 <- function() {

  ## Graphical settings
  str     <- trellis.par.get("strip.background")
  str$col <- rep("transparent",length(str$col))
  trellis.par.set("strip.background",str)
  
  str     <- trellis.par.get("strip.shingle")
  str$col <- rep("transparent",length(str$col))
  trellis.par.set("strip.shingle",str)

  grl     <- trellis.par.get("reference.line")
  grl$col <- "black"
  grl$lty <- 3
  trellis.par.set("reference.line",grl)

  ## Create subset
  adata  <- datab4
  ids    <- unique(adata[,"ID"])
  tmp    <- data.frame(ID=ids,
                       R=sample(c(0,1),size=length(ids),
                         replace=TRUE,
                         prob=c(0.5,0.5)))
  
  newdata             <- merge(adata,tmp,by="ID")
  newdata             <- newdata[newdata$WRES!=0 & newdata$TAD!=0,]
  ids                 <- newdata[,"ID"]
  
  newdata$cCRCL <- cut(newdata$CRCL,
                       br=quantile(newdata$CRCL[!duplicated(newdata$ID)],
                         pr=c(0,1/3,2/3,1)),
                       include.lowest=T)

  levels(newdata$cCRCL) <- c("Low Creatinine clearance",
                             "Medium Creatinine clearance",
                             "High Creatinine clearance")
  
  xplot <- xyplot(DV~TAD|cCRCL, 
                  data=newdata,
                  groups = ID,
                  aspect=1,
                  layout=c(3,1),
                  ids  = ids,
                  xlab = "Time after dose (h)",
                  ylab = "Observed concentration (ng/mL)",
                  panel=function(x,y,ids,subscripts,...) {
                    ord <- order(x)
                    panel.grid()
                    panel.superpose(x[ord],y[ord],subscripts[ord],...,
                                    type="b",pch="o",cex=0.7,
                                    col="black",lty=1)
                    
                    panel.loess(x,
                                y,lwd=4,lty=1,col="black")
                    
                    ## Adding the id-labels
                    idd  <- ids[subscripts]
                    yres <- residuals(loess(y~x))

                    ord     <- order(yres)
                    ordy    <- y[ord]
                    ordx    <- x[ord]
                    ordidd  <- idd[ord]
                    ## Number of data points to plot
                    idsext <- ceiling(length(x)*0.02)

                    ll <- length(ordx)
                    
                    ## Upper points
                    ltext(ordx[(ll-idsext+1):ll],
                          ordy[(ll-idsext+1):ll],
                             ordidd[(ll-idsext+1):ll],
                             cex=0.7)
                    ## Lower points
                    ltext(ordx[1:idsext],
                             ordy[1:idsext],
                             ordidd[1:idsext],
                             cex=0.7)
                  }
                  )

  print(xplot)
  invisible()
}
