figure9 <- function() {

  library(lattice)

  ## Graphical settings
  str     <- trellis.par.get("strip.background")
  str$col <- rep("transparent",length(str$col))
  trellis.par.set("strip.background",str)

  grl     <- trellis.par.get("reference.line")
  grl$col <- "black"
  grl$lty <- 3
  trellis.par.set("reference.line",grl)

  adata <- datab4 #sdtab4 
  adata <- adata[adata$WRES!=0,]

  ## Create subset
  subci  <- 0.99 # The limits of the sampling region
  frac   <- 0.250  # Probability of being plotted if in the region

  yres <- residuals(loess(DV~TIME,adata))
  lims <- quantile(yres,
                   probs=c(1-subci,subci))
  

  mp3fun <- function(x,lims) {
    ret <- 1
    if(any(x < lims[1])) ret <- 0
    if(any(x > lims[2])) ret <- 0
    ret
  }
  
  RR     <- tapply(yres,adata$ID,FUN="mp3fun",lim=lims)
  ids    <- unique(adata[,"ID"])
  RRR    <- sample(c(0,1),size=length(ids),replace=TRUE,
                   prob=c(frac,1-frac))
                         
  tmp    <- data.frame(ID=as.factor(names(RR)),
                       R=RR*RRR)
                
  names(tmp) <- c("ID","R")
  data       <- merge(tmp,adata,by="ID",sort=FALSE)

  ## Select data points to plot ID numbers for
  yres <- residuals(loess(data$DV~data$TAD))
  lims <- quantile(yres,prob=c(0.02,0.98))

  data[,"RR"] <- ifelse(yres <= lims[1],1,0)
  data[,"RR"] <- ifelse(yres >= lims[2],1,data$RR)
    
  data.stack <- stack(data,c("DV","IPRE","PRED"))
  data.stack[,"ID"] <- rep(data$ID,3)
  data.stack[,"TAD"] <- rep(data$TAD,3)
  data.stack[,"R"] <- rep(data$R,3)
  data.stack[,"RR"] <- rep(data$RR,3)
  levels(data.stack$ind) <- c("Observations","Individual predictions",
                              "Population predictions")
  xplot <- xyplot(values~TAD|ind,data.stack,
                  groups=ID,
                  ylab = "Observations/Predictions (ng/mL)",
                  xlab = "Time after dose (h)",
                  adat = data.stack,
                  ids = data.stack[,"ID"],
                  rr  = data.stack[,"RR"],
                  subset = R==0,
                  layout=c(3,1),
                  aspect=1,
                  panel=function(x,y,subscripts,adat,ids,rr,...) {
                    ord <- order(x)
                    panel.grid()
                    panel.superpose(x[ord],y[ord],subscripts[ord],
                                    ...,type="b",pch=1,cex=0.7,lty=1,
                                    col="black")
                    panel.loess(adat$TAD[subscripts],adat$values[subscripts],
                                ...,lwd=3,col="black")
                                
                    idd <- ids[subscripts]
                    ltext(x[rr[subscripts]==1],y[rr[subscripts]==1],
                          idd[rr[subscripts]==1],
                          cex=0.7)
                  }
                  )
  print(xplot)
  invisible()
}
