read.nm.tables <-  function(runno,tab.suffix="",
                            table.names=c("sdtab","mutab","patab","catab",
                              "cotab","mytab","extra","xptab")) {

  tab.files <- sapply(table.names,paste,runno,tab.suffix,sep="")

  ## Read in the table files
  totab      <- NULL
  totnam     <- NULL
  seen.files <- NULL
  filedim    <- NULL

  for(i in 1:length(tab.files)) {
    filename <- tab.files[i]

    if(!is.readable.file(filename)) {
      next
      
    } else {
      ## Check if we have unequal number of filds in the file
      if(length(unique(count.fields(filename,skip=1)))!=1) {
        cat("Found different number of fields in ",filename,".\n")
        cat("This may be due to multiple TABLE and header rows.\n")
        cat("Will try to remove them. It may take a while...\n")
        
        tmp   <- readLines(filename, n = -1)
        inds  <- grep("TABLE",tmp)
        inds  <- inds[c(2:length(inds))]
        inds2 <- inds+1
        tempfile<- paste(filename,".xptmp",sep="")
        write.table(tmp[-c(inds,inds2)],file=tempfile,
                    row.names=FALSE,quote=FALSE)
        assign(paste("n.",filename,sep=""),read.table(tempfile,skip=2,h=T))
        unlink(tempfile)
        
      } else {
        assign(paste("n.",filename,sep=""),read.table(filename,skip=1,h=T))
      }
      
      ## Remember the files seen
      if(is.null(seen.files)) {
        seen.files <- paste("n.",filename,sep="")
      } else {
        seen.files <- c(seen.files,paste("n.",filename,sep=""))
      }
    }
  }

  ## Check if we found any table files
  if(any(is.null(seen.files))) {
    cat("Couldn't find any table files that match run number", 
    runno, "\n")
    return(NULL)
  }

  ## Check if the files have the same length
  for(nfile in seen.files) {
    if(is.null(filedim)) {
      filedim <- nrow(get(nfile))
    } else {
      filedim <- c(filedim,nrow(get(nfile)))
    }
  }
  
  file.df <- data.frame(seen.files=seen.files,filedim=filedim)
  lngths  <- sort(unique(file.df$filedim))
  if(length(lngths) !=1) {
    cat("\nThe table files associated with this run number(",runno,
        ") appear\n")
    cat("to have different lengths ")
    smallest <- lngths[1]
    for(sz in lngths[2:length(lngths)]) {
      if(regexpr("\\.",as.character(sz/smallest))!=-1) {
        cat("and the shortest of size",smallest)
        cat(" is not an even multiple of",sz,".\n")
        cat("You will have to sort this out and try again.\n")
        return(NULL)
      }
    }
    cat("but the shortest file seems to be an even multple\n")
    cat("of the other files.\n")
    
  }

  ## Add the tables to totab and replicate the shorter ones to match
  ## the size of the longest one
  maxlngth <- max(file.df$filedim)
  
  for(ii in 1:nrow(file.df)) {
    filnam <- as.character(file.df[ii,"seen.files"])
    new.df <- get(filnam)
    sz     <- file.df[ii,"filedim"]
    rl     <- maxlngth/sz

    if(any(is.null(totab))) {
      totab <- data.frame(lapply(new.df,
                                 function(x,rl) {rep(x,rl)},rl))
      totnam <- c(totnam,names(new.df))
    } else {
      totab <- cbind(totab,
                     data.frame(lapply(new.df,function(x,rl) {
                       rep(x,rl)},rl)))
      totnam <- c(totnam,names(new.df))
    }
  }
  
  ## Delete all duplicates
  totab <- totab[, !duplicated(totnam)]



  return(totab)
}
